matminer.data_retrieval.tests package — matminer 0.6.3 documentation

# matminer.data_retrieval.tests package

## Submodules

## matminer.data_retrieval.tests.test_retrieve_AFLOW module

## matminer.data_retrieval.tests.test_retrieve_Citrine module

class `matminer.data_retrieval.tests.test_retrieve_Citrine.` `CitrineDataRetrievalTest`(methodName='runTest')

  Bases: `unittest.case.TestCase`

  `setUp`()

    Hook method for setting up the test fixture before exercising it.

  `test_get_data`()
  `test_multiple_items_in_list`()

## matminer.data_retrieval.tests.test_retrieve_MDF module

class `matminer.data_retrieval.tests.test_retrieve_MDF.` `MDFDataRetrievalTest`(methodName='runTest')

  Bases: `unittest.case.TestCase`

  classmethod `setUpClass`()

    Hook method for setting up class fixture before running tests in the class.

  `test_get_dataframe`()
  `test_get_dataframe_by_query`()
  `test_make_dataframe`()

## matminer.data_retrieval.tests.test_retrieve_MP module

class `matminer.data_retrieval.tests.test_retrieve_MP.` `MPDataRetrievalTest`(methodName='runTest')

  Bases: `unittest.case.TestCase`

  `setUp`()

    Hook method for setting up the test fixture before exercising it.

  `test_get_data`()

## matminer.data_retrieval.tests.test_retrieve_MPDS module

class `matminer.data_retrieval.tests.test_retrieve_MPDS.` `MPDSDataRetrievalTest`(methodName='runTest')

  Bases: `unittest.case.TestCase`

  `setUp`()

    Hook method for setting up the test fixture before exercising it.

  `test_valid_answer`()

## matminer.data_retrieval.tests.test_retrieve_MongoDB module

class `matminer.data_retrieval.tests.test_retrieve_MongoDB.` `MongoDataRetrievalTest`(methodName='runTest')

  Bases: `unittest.case.TestCase`

  `test_cleaned_projection`()
  `test_remove_ints`()

## Module contents